==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/input_file_location.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputFileLocation = Union[raw.types.InputDocumentFileLocation, raw.types.InputEncryptedFileLocation, raw.types.InputFileLocation, raw.types.InputPeerPhotoFileLocation, raw.types.InputPhotoFileLocation, raw.types.InputPhotoLegacyFileLocation, raw.types.InputSecureFileLocation, raw.types.InputStickerSetThumb, raw.types.InputTakeoutFileLocation]


# noinspection PyRedeclaration
class InputFileLocation(TLObject):  # type: ignore
    """This base type has 9 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputDocumentFileLocation <pyrogram.raw.types.InputDocumentFileLocation>`
            - :obj:`InputEncryptedFileLocation <pyrogram.raw.types.InputEncryptedFileLocation>`
            - :obj:`InputFileLocation <pyrogram.raw.types.InputFileLocation>`
            - :obj:`InputPeerPhotoFileLocation <pyrogram.raw.types.InputPeerPhotoFileLocation>`
            - :obj:`InputPhotoFileLocation <pyrogram.raw.types.InputPhotoFileLocation>`
            - :obj:`InputPhotoLegacyFileLocation <pyrogram.raw.types.InputPhotoLegacyFileLocation>`
            - :obj:`InputSecureFileLocation <pyrogram.raw.types.InputSecureFileLocation>`
            - :obj:`InputStickerSetThumb <pyrogram.raw.types.InputStickerSetThumb>`
            - :obj:`InputTakeoutFileLocation <pyrogram.raw.types.InputTakeoutFileLocation>`
    """

    QUALNAME = "pyrogram.raw.base.InputFileLocation"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/input_file_location.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputFileLocation = Union[raw.types.InputDocumentFileLocation, raw.types.InputEncryptedFileLocation, raw.types.InputFileLocation, raw.types.InputPeerPhotoFileLocation, raw.types.InputPhotoFileLocation, raw.types.InputPhotoLegacyFileLocation, raw.types.InputSecureFileLocation, raw.types.InputStickerSetThumb, raw.types.InputTakeoutFileLocation]


# noinspection PyRedeclaration
class InputFileLocation:  # type: ignore
    """This base type has 9 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputDocumentFileLocation <pyrogram.raw.types.InputDocumentFileLocation>`
            - :obj:`InputEncryptedFileLocation <pyrogram.raw.types.InputEncryptedFileLocation>`
            - :obj:`InputFileLocation <pyrogram.raw.types.InputFileLocation>`
            - :obj:`InputPeerPhotoFileLocation <pyrogram.raw.types.InputPeerPhotoFileLocation>`
            - :obj:`InputPhotoFileLocation <pyrogram.raw.types.InputPhotoFileLocation>`
            - :obj:`InputPhotoLegacyFileLocation <pyrogram.raw.types.InputPhotoLegacyFileLocation>`
            - :obj:`InputSecureFileLocation <pyrogram.raw.types.InputSecureFileLocation>`
            - :obj:`InputStickerSetThumb <pyrogram.raw.types.InputStickerSetThumb>`
            - :obj:`InputTakeoutFileLocation <pyrogram.raw.types.InputTakeoutFileLocation>`
    """

    QUALNAME = "pyrogram.raw.base.InputFileLocation"
